@@ -12,7 +12,7 @@ import matplotlib.gridspec as gridspec
 import matplotlib.cm as cmx
 import math
 import pyfastaq
-from ariba import common, reference_data
+from ariba import reference_data
 
 class Error (Exception): pass
 
