@@ -42,7 +42,7 @@ class RefGenesGetter:
     def _get_card_versions(self, tmp_file):
         print('Getting available CARD versions')
         common.download_file('https://card.mcmaster.ca/download', tmp_file, max_attempts=self.max_download_attempts, sleep_time=self.sleep_time, verbose=True)
-        p = re.compile(r'''href="(/download/.*?broad.*?v([0-9]+\.[0-9]+\.[0-9]+)\.tar\.(gz|bz2))"''')
+        p = re.compile(r'''href="(/download/0/.*?broad.*?v([0-9]+\.[0-9]+\.[0-9]+)\.tar\.(gz|bz2))"''')
         versions = {}
 
         with open(tmp_file) as f:
@@ -183,7 +183,7 @@ class RefGenesGetter:
         print('You can use them with ARIBA like this:')
         print('ariba prepareref -f', final_fasta, '-m', final_tsv, 'output_directory\n')
         print('If you use this downloaded data, please cite:')
-        print('"The Comprehensive Antibiotic Resistance Database", McArthur et al 2013, PMID: 23650175')
+        print('"CARD 2020: antibiotic resistome surveillance with the comprehensive antibiotic resistance database", Alcock et al 2020, PMID: 31665441')
         print('and in your methods say that version', self.version, 'of the database was used')
 
 
@@ -611,13 +611,7 @@ class RefGenesGetter:
             #up to here
         if len(acc_list) > 0:
             print(f"E-fetching {len(acc_list)} genbank records from BioProject {BIOPROJECT} and writing to.  This may take a while.", file=sys.stderr)
-            records = Entrez.efetch(db="nucleotide",
-                                               rettype="gbwithparts", retmode="text",
-                                               retstart=0, retmax=RETMAX,
-                                               webenv=webenv, query_key=query_key,
-                                               idtype="acc")
             #pull out the records as fasta from the genbank
-            from Bio.Alphabet import generic_dna
             from Bio import SeqIO
             from Bio.Seq import Seq
             from Bio.SeqRecord import SeqRecord
@@ -625,8 +619,16 @@ class RefGenesGetter:
             print(f"Parsing genbank records.")
             with open(final_fasta, "w") as f_out_fa, \
                  open(final_tsv, "w") as f_out_tsv:
-                for idx, gb_record in enumerate(SeqIO.parse(records, "genbank")):
-                    print(f"'{gb_record.id}'")
+                for idx, record_id in enumerate(acc_list):
+                    print(f"'{record_id}'")
+                    if record_id.startswith('AP'):
+                        print('skipping')
+                        continue
+                    record = Entrez.efetch(db="nucleotide",
+                                                rettype="gbwithparts", retmode="text",
+                                                id=record_id)
+                    gb_record = SeqIO.read(record, "genbank")
+
                     n=0
                     record_new=[]
                     for index, feature in enumerate(gb_record.features):
@@ -645,7 +647,7 @@ class RefGenesGetter:
                                 except KeyError:
                                     print(f"gb_feature.qualifer not found", file=sys.stderr)
                             accession = gb_record.id
-                            seq_out = Seq(str(gb_feature.extract(gb_record.seq)), generic_dna)
+                            seq_out = Seq(str(gb_feature.extract(gb_record.seq)))
                             record_new.append(SeqRecord(seq_out,
                                          id=f"{id[0]}.{accession}",
                                          description=""))
@@ -659,6 +661,6 @@ class RefGenesGetter:
                         print('ariba prepareref -f', final_fasta, '-m', final_tsv, 'output_directory\n')
 
         else:
-            print(f"Nothing to do. Exiting.")    
+            print(f"Nothing to do. Exiting.")
     def run(self, outprefix):
         exec('self._get_from_' + self.ref_db + '(outprefix)')
