@@ -64,8 +64,8 @@ def run(options):
         options.outprefix,
         fofn=options.fofn,
         filenames=options.infiles,
-        filter_rows=options.col_filter == 'y',
-        filter_columns=options.row_filter == 'y',
+        filter_rows=options.row_filter == 'y',
+        filter_columns=options.col_filter == 'y',
         min_id=options.min_id,
         cluster_cols=options.cluster_cols,
         make_phandango_tree=(not options.no_tree),
